@@ -1,6 +1,27 @@
+import pandas as pd
+import numpy as np
+import nltk
+from nltk.corpus import stopwords
+from nltk.corpus import wordnet
+from nltk.tokenize import word_tokenize, sent_tokenize
+from nltk.stem.wordnet import WordNetLemmatizer 
+nltk.download('punkt')
+nltk.download('averaged_perceptron_tagger')
+nltk.download('stopwords')
+import subprocess
+
+def install(name):
+    subprocess.call(['pip', 'install', name])
+
+install('stanza')
+
+import stanza
+stanza.download('en')
+nlp = stanza.Pipeline('en')
+
+
 class Aspect:
     def recognizer(txt):
-        nlp = stanza.Pipeline('en')
         txt = txt.lower()
         sentList = nltk.sent_tokenize(txt)
         for line in sentList:
@@ -57,4 +78,4 @@ class Aspect:
                         filist.append(j[0])
             fcluster.append([i[0], filist])
         #print(fcluster)
-        return categories   
\ No newline at end of file
+        return categories   
